Logging Options
---------------

Logging options which override any settings defined on the configuration files.

.. start-console-output
.. option:: -l LOG_LEVEL, --log-level=LOG_LEVEL

    Console logging log level. One of ``all``, ``garbage``, ``trace``,
    ``debug``, ``info``, ``warning``, ``error``, ``quiet``. Default:
    |loglevel|.
.. stop-console-output

.. option:: --log-file=LOG_FILE

    Log file path. Default: |logfile|.

.. option:: --log-file-level=LOG_LEVEL_LOGFILE

    Logfile logging log level. One of ``all``, ``garbage``, ``trace``,
    ``debug``, ``info``, ``warning``, ``error``, ``quiet``. Default:
    |loglevel|.
